@@ -1,7 +1,7 @@
 from mysql.toolkit.components.connector import Connector
 from mysql.toolkit.components.query import Query
-from mysql.toolkit.components.sql import SQL
+from mysql.toolkit.components.structure import Structure
 from mysql.toolkit.components.operations import Operations
 
 
-__all__ = ['Connector', 'Query', 'SQL', 'Operations']
+__all__ = ['Connector', 'Query', 'Structure', 'Operations']
