@@ -1,18 +1,14 @@
-from mysql.toolkit.components import Connector, Query, SQL, Operations
+from mysql.toolkit.components import Connector, Query, Structure, Operations
 
 
-class MySQL(Connector, Query, SQL, Operations):
+class MySQL(Connector, Query, Structure, Operations):
     def __init__(self, config, enable_printing=True):
         """
         Connect to MySQL database and execute queries
         :param config: MySQL server configuration settings
         """
         # Initialize inherited classes
-        super().__init__(config, enable_printing)
-        # Connector.__init__(self, config, enable_printing)
-        # Core.__init__(self)
-        # Results.__init__(self)
-        # Advanced.__init__(self)
+        Connector.__init__(self, config, enable_printing)
 
     def __enter__(self):
         return self
