@@ -21,7 +21,7 @@ def get_col_val_str(columns, query_type='insert'):
 
 def join_cols(cols):
     """Join list of columns into a string for a SQL query"""
-    return ", ".join([i for i in cols]) if isinstance(cols, list) else cols
+    return ", ".join([i for i in cols]) if isinstance(cols, (list, tuple, set)) else cols
 
 
 def wrap(item):
